# Bosch Nefit Easy™ Client

## Install
```bash
pip install nefit-client
```

## Usage
```bash
usage: Nefit client [options]

Nefit client

optional arguments:
  -h, --help            show this help message and exit
  --serial SERIAL       Serial, 9 number digit
  --access-key ACCESS_KEY
                        Access key, 12 long
  --password PASSWORD   Password, usually postalcode + housenumber
  --status              Status
  --get-year-total      Display the current total gas usage
  --display-code        Display code
  --set-temperature SET_TEMPERATURE
                        Set temperature
  -v, --verbose         Increase output verbosity
  --version             show program s version number and exit
```
